@@ -1,3 +1,4 @@
+import json
 import typing
 
 import settings
@@ -65,6 +66,14 @@ class ScraperManager:
 
         return f"{self.WEBSITE_BASE_URL}{url}"
 
+    def parse_json(self, data, default=None, *args, **kwargs):
+        default = default or {}
+        return self.handler(lambda: json.loads(data, *args, **kwargs), default=default)
+
+    def dump_json(self, data, default=None, *args, **kwargs):
+        default = default or {}
+        return self.handler(lambda: json.dumps(data, *args, **kwargs), default=default)
+
     def get_product_detail_template(self, **kwargs):
         return {**self.PRODUCT_DETAIL_PAGE_TEMPLATE, **kwargs}
 
